"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.shutdownConsumers = exports.getConsumer = void 0;
const config_1 = require("./config");
const bluebird_1 = require("bluebird");
const redis_smq_1 = require("redis-smq");
const common_1 = require("./common");
let consumersList = [];
function getConsumer(args = {}) {
    const { queue = common_1.defaultQueue, messageHandler = (msg, cb) => cb(), cfg = config_1.config, } = args;
    const consumer = (0, bluebird_1.promisifyAll)(new redis_smq_1.Consumer(cfg));
    consumer.consume(queue, messageHandler, () => void 0);
    consumersList.push(consumer);
    return consumer;
}
exports.getConsumer = getConsumer;
function shutdownConsumers() {
    return __awaiter(this, void 0, void 0, function* () {
        for (const i of consumersList) {
            if (i.isGoingUp()) {
                yield new Promise((resolve) => {
                    i.once(redis_smq_1.events.UP, resolve);
                });
            }
            if (i.isRunning()) {
                yield new Promise((resolve) => {
                    i.shutdown(resolve);
                });
            }
        }
        consumersList = [];
    });
}
exports.shutdownConsumers = shutdownConsumers;
//# sourceMappingURL=consumers.js.map