"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scheduleMessage = exports.produceAndAcknowledgeMessage = exports.produceAndDeadLetterMessage = exports.produceMessage = exports.produceMessageWithPriority = exports.createQueue = void 0;
const config_1 = require("./config");
const bluebird_1 = require("bluebird");
const redis_smq_1 = require("redis-smq");
const consumer_events_1 = require("./consumer-events");
const producers_1 = require("./producers");
const consumers_1 = require("./consumers");
const queue_manager_1 = require("./queue-manager");
const common_1 = require("./common");
function createQueue(queue, priorityQueuing) {
    return __awaiter(this, void 0, void 0, function* () {
        const qm = yield (0, queue_manager_1.getQueueManagerAsync)();
        yield qm.queue.createAsync(queue, priorityQueuing);
    });
}
exports.createQueue = createQueue;
function produceMessageWithPriority(queue = common_1.defaultQueue, cfg = config_1.config) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = (0, bluebird_1.promisifyAll)((0, producers_1.getProducer)(cfg));
        const message = new redis_smq_1.Message();
        message.setPriority(redis_smq_1.Message.MessagePriority.LOW).setQueue(queue);
        yield producer.produceAsync(message);
        return { message, producer, queue };
    });
}
exports.produceMessageWithPriority = produceMessageWithPriority;
function produceMessage(queue = common_1.defaultQueue, cfg = config_1.config) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = (0, producers_1.getProducer)(cfg);
        const message = new redis_smq_1.Message();
        message.setBody({ hello: 'world' }).setQueue(queue);
        yield producer.produceAsync(message);
        return { producer, message, queue };
    });
}
exports.produceMessage = produceMessage;
function produceAndDeadLetterMessage(queue = common_1.defaultQueue, cfg = config_1.config) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = (0, producers_1.getProducer)(cfg);
        const consumer = (0, consumers_1.getConsumer)({
            cfg,
            queue,
            messageHandler: jest.fn(() => {
                throw new Error('Explicit error');
            }),
        });
        const message = new redis_smq_1.Message();
        message.setBody({ hello: 'world' }).setQueue(queue);
        yield producer.produceAsync(message);
        consumer.run();
        yield (0, consumer_events_1.untilConsumerEvent)(consumer, redis_smq_1.events.MESSAGE_DEAD_LETTERED);
        return { producer, consumer, message, queue };
    });
}
exports.produceAndDeadLetterMessage = produceAndDeadLetterMessage;
function produceAndAcknowledgeMessage(queue = common_1.defaultQueue, cfg = config_1.config) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = (0, producers_1.getProducer)(cfg);
        const consumer = (0, consumers_1.getConsumer)({
            cfg,
            queue,
            messageHandler: jest.fn((msg, cb) => {
                cb();
            }),
        });
        const message = new redis_smq_1.Message();
        message.setBody({ hello: 'world' }).setQueue(queue);
        yield producer.produceAsync(message);
        consumer.run();
        yield (0, consumer_events_1.untilMessageAcknowledged)(consumer);
        return { producer, consumer, queue, message };
    });
}
exports.produceAndAcknowledgeMessage = produceAndAcknowledgeMessage;
function scheduleMessage(queue = common_1.defaultQueue, cfg = config_1.config) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = (0, bluebird_1.promisifyAll)((0, producers_1.getProducer)(cfg));
        const message = new redis_smq_1.Message();
        message.setScheduledDelay(10000).setQueue(queue);
        yield producer.produceAsync(message);
        return { message, producer, queue };
    });
}
exports.scheduleMessage = scheduleMessage;
//# sourceMappingURL=message-producing.js.map