"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateTimeSeriesFrom = exports.listenForWebsocketStreamEvents = void 0;
const websocket_rate_stream_worker_1 = require("./websocket-rate-stream-worker");
const bluebird_1 = require("bluebird");
const monitor_server_1 = require("./monitor-server");
const supertest = require("supertest");
const redis_clients_1 = require("./redis-clients");
function listenForWebsocketStreamEvents(streamName, startFn = websocket_rate_stream_worker_1.startWebsocketRateStreamWorker) {
    return __awaiter(this, void 0, void 0, function* () {
        yield startFn();
        const subscribeClient = yield (0, redis_clients_1.getRedisInstance)();
        subscribeClient.subscribe(streamName);
        const data = [];
        subscribeClient.on('message', (channel, message) => {
            const payload = JSON.parse(message);
            data.push({ ts: Date.now(), payload });
        });
        for (; true;) {
            if (data.length === 10) {
                subscribeClient.unsubscribe(streamName);
                break;
            }
            else
                yield (0, bluebird_1.delay)(500);
        }
        return data;
    });
}
exports.listenForWebsocketStreamEvents = listenForWebsocketStreamEvents;
function validateTimeSeriesFrom(url) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, monitor_server_1.startMonitorServer)();
        const request = supertest('http://127.0.0.1:3000');
        const timestamp = Math.ceil(Date.now() / 1000);
        const from = timestamp - 60;
        const response1 = yield request.get(`${url}?from=${from}&to=${timestamp}`);
        expect(response1.statusCode).toBe(200);
        const data = (_a = response1.body.data) !== null && _a !== void 0 ? _a : [];
        expect(data.length).toEqual(60);
        expect(data[0]).toEqual({
            timestamp: from,
            value: 0,
        });
        expect(data[59]).toEqual({
            timestamp: timestamp - 1,
            value: 0,
        });
    });
}
exports.validateTimeSeriesFrom = validateTimeSeriesFrom;
//# sourceMappingURL=websocket-event.js.map