"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const supertest = require("supertest");
const message_producing_1 = require("../../common/message-producing");
const monitor_server_1 = require("../../common/monitor-server");
const redis_smq_1 = require("redis-smq");
const producers_1 = require("../../common/producers");
const common_1 = require("../../common/common");
test('Fetching and deleting scheduled messages using the HTTP API: Case 1', () => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c, _d, _e, _f, _g;
    yield (0, message_producing_1.createQueue)(common_1.defaultQueue, false);
    yield (0, monitor_server_1.startMonitorServer)();
    const producer = (0, producers_1.getProducer)();
    const msg1 = new redis_smq_1.Message();
    msg1
        .setScheduledCRON('0 * * * * *')
        .setBody({ hello: 'world1' })
        .setQueue(common_1.defaultQueue);
    yield producer.produceAsync(msg1);
    const request = supertest('http://127.0.0.1:3000');
    const response1 = yield request.get('/api/main/scheduled-messages?skip=0&take=100');
    expect(response1.statusCode).toBe(200);
    expect(response1.body.data).toBeDefined();
    expect((_a = response1.body.data) === null || _a === void 0 ? void 0 : _a.total).toBe(1);
    expect((_b = response1.body.data) === null || _b === void 0 ? void 0 : _b.items.length).toBe(1);
    expect((_d = (_c = response1.body.data) === null || _c === void 0 ? void 0 : _c.items[0].message.metadata) === null || _d === void 0 ? void 0 : _d.uuid).toBe(msg1.getRequiredId());
    const response2 = yield request.delete(`/api/main/scheduled-messages/${msg1.getRequiredId()}?sequenceId=${(_e = response1.body.data) === null || _e === void 0 ? void 0 : _e.items[0].sequenceId}`);
    expect(response2.statusCode).toBe(204);
    expect(response2.body).toEqual({});
    const response3 = yield request.get('/api/main/scheduled-messages?skip=0&take=100');
    expect(response3.statusCode).toBe(200);
    expect(response3.body.data).toBeDefined();
    expect((_f = response3.body.data) === null || _f === void 0 ? void 0 : _f.total).toBe(0);
    expect((_g = response3.body.data) === null || _g === void 0 ? void 0 : _g.items.length).toBe(0);
}));
//# sourceMappingURL=test00001.test.js.map