"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = require("bluebird");
const redis_clients_1 = require("../../common/redis-clients");
const time_series_1 = require("../../../src/plugins/message-rate/common/time-series");
const sorted_set_time_series_1 = require("../../../src/plugins/message-rate/common/sorted-set-time-series");
test('SortedSetTimeSeries: Case 1', () => __awaiter(void 0, void 0, void 0, function* () {
    const redisClient = yield (0, redis_clients_1.getRedisInstance)();
    const sortedSetTimeSeries = (0, bluebird_1.promisifyAll)(new sorted_set_time_series_1.SortedSetTimeSeries(redisClient, {
        key: 'my-key',
        retentionTimeInSeconds: 20,
    }));
    const multi = redisClient.multi();
    const ts = time_series_1.TimeSeries.getCurrentTimestamp();
    sortedSetTimeSeries.add(ts, 100, multi);
    sortedSetTimeSeries.add(ts + 3, 56, multi);
    sortedSetTimeSeries.add(ts + 10, 70, multi);
    yield redisClient.execMultiAsync(multi);
    const range = yield sortedSetTimeSeries.getRangeAsync(ts - 20, ts + 20);
    expect(range.length).toBe(40);
    expect(range[0]).toEqual({ timestamp: ts - 20, value: 0 });
    expect(range[20]).toEqual({ timestamp: ts, value: 100 });
    expect(range[23]).toEqual({ timestamp: ts + 3, value: 56 });
    expect(range[30]).toEqual({ timestamp: ts + 10, value: 70 });
    expect(range[39]).toEqual({ timestamp: ts + 20 - 1, value: 0 });
}));
//# sourceMappingURL=test00006.test.js.map