"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = require("bluebird");
const redis_clients_1 = require("../../common/redis-clients");
const time_series_1 = require("../../../src/plugins/message-rate/common/time-series");
const sorted_set_time_series_1 = require("../../../src/plugins/message-rate/common/sorted-set-time-series");
const time_series_clean_up_worker_1 = require("../../common/time-series-clean-up-worker");
test('SortedSetTimeSeries: Case 2', () => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, time_series_clean_up_worker_1.startTimeSeriesWorker)();
    const redisClient = yield (0, redis_clients_1.getRedisInstance)();
    const sortedSetTimeSeries = (0, bluebird_1.promisifyAll)(new sorted_set_time_series_1.SortedSetTimeSeries(redisClient, {
        key: 'my-key',
        retentionTimeInSeconds: 5,
    }));
    const ts = time_series_1.TimeSeries.getCurrentTimestamp();
    for (let i = 0; i < 10; i += 1) {
        yield sortedSetTimeSeries.addAsync(ts + i, i);
    }
    const range1 = yield sortedSetTimeSeries.getRangeAsync(ts, ts + 10);
    yield (0, bluebird_1.delay)(15000);
    yield sortedSetTimeSeries.cleanUpAsync();
    const range2 = yield sortedSetTimeSeries.getRangeAsync(ts, ts + 10);
    expect(range1.length).toEqual(10);
    expect(range1[0]).toEqual({ timestamp: ts, value: 0 });
    expect(range1[1]).toEqual({ timestamp: ts + 1, value: 1 });
    expect(range1[2]).toEqual({ timestamp: ts + 2, value: 2 });
    expect(range1[3]).toEqual({ timestamp: ts + 3, value: 3 });
    expect(range1[4]).toEqual({ timestamp: ts + 4, value: 4 });
    expect(range1[5]).toEqual({ timestamp: ts + 5, value: 5 });
    expect(range1[6]).toEqual({ timestamp: ts + 6, value: 6 });
    expect(range1[7]).toEqual({ timestamp: ts + 7, value: 7 });
    expect(range1[8]).toEqual({ timestamp: ts + 8, value: 8 });
    expect(range1[9]).toEqual({ timestamp: ts + 9, value: 9 });
    expect(range2.length).toEqual(10);
    expect(range2[0]).toEqual({ timestamp: ts, value: 0 });
    expect(range2[1]).toEqual({ timestamp: ts + 1, value: 0 });
    expect(range2[2]).toEqual({ timestamp: ts + 2, value: 0 });
    expect(range2[3]).toEqual({ timestamp: ts + 3, value: 0 });
    expect(range2[4]).toEqual({ timestamp: ts + 4, value: 0 });
    expect(range2[5]).toEqual({ timestamp: ts + 5, value: 0 });
    expect(range2[6]).toEqual({ timestamp: ts + 6, value: 0 });
    expect(range2[7]).toEqual({ timestamp: ts + 7, value: 0 });
    expect(range2[8]).toEqual({ timestamp: ts + 8, value: 0 });
    expect(range2[9]).toEqual({ timestamp: ts + 9, value: 0 });
}));
//# sourceMappingURL=test00007.test.js.map